@@ -1,15 +1,13 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Output::HTML::TicketMenu::Move;
 
-use parent 'Kernel::Output::HTML::Base';
-
 use strict;
 use warnings;
 
@@ -21,6 +19,19 @@ our @ObjectDependencies = (
     'Kernel::Output::HTML::Layout',
 );
 
+sub new {
+    my ( $Type, %Param ) = @_;
+
+    # allocate new hash for object
+    my $Self = {};
+    bless( $Self, $Type );
+
+    # get UserID param
+    $Self->{UserID} = $Param{UserID} || die "Got no UserID!";
+
+    return $Self;
+}
+
 sub Run {
     my ( $Self, %Param ) = @_;
 
@@ -120,11 +131,10 @@ sub Run {
             Action   => $LayoutObject->{Action},
             Type     => 'move_into',
         );
-        $MoveQueues{0}         = '- ' . $LayoutObject->{LanguageObject}->Translate('Move') . ' -';
+        $MoveQueues{0} = '- ' . $LayoutObject->{LanguageObject}->Translate('Move') . ' -';
         $Param{MoveQueuesStrg} = $LayoutObject->AgentQueueListOption(
-            Name  => 'DestQueueID',
-            Data  => \%MoveQueues,
-            Class => 'Modernize',
+            Name => 'DestQueueID',
+            Data => \%MoveQueues,
         );
     }
     else {
